;+
; .. _fig4_met_var_correction_scatter.pro:
;
; ===================================
; fig4_met_var_correction_scatter.pro
; ===================================
;
; DESCRIPTION
; ===========
;
; .. graphviz::
;
;    digraph fig4_met_var_correction_scatter {
;
;       sst [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/sst_correction_final.txt"];
;       t2m [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/t2m_correction_final.txt"];
;       q2m [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/q2m_correction_final.txt"];
;       ws  [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/ws_correction_final.txt"];
;
;       figure [shape=ellipse,fontname=Courier,label="${PROJECT_OD}/fig4_met_var_correction_scatter.ps"];
;
;       fig4_met_var_correction_scatter [shape=box,
;       fontname=Courier,
;       color=blue,
;       URL="http://forge.ipsl.jussieu.fr/tropflux/browser/trunk/src/paper01/fig4/fig4_met_var_correction_scatter.pro",
;       label="${TROPFLUX}/src/paper01/fig4/fig4_met_var_correction_scatter.pro"];
;
;       {sst t2m q2m ws} -> {fig4_met_var_correction_scatter} -> {figure}
;    }
;
; SEE ALSO
; ========
;
; :ref:`project_profile.sh`
; :ref:`project_init.pro`
;
; :ref:`significance_test_99.pro`
;
; EXAMPLES
; ========
;
; ::
;
;  IDL> fig4_met_var_correction_scatter
;
; TODO
; ====
;
; check results
;
; improve plot
;
; coding rules
;
; complete description
;
; handle IO error
;
; EVOLUTIONS
; ==========
;
; $Id$
;
; $URL$
;
; - pinsard 2011-04-20T15:27:24Z loholt1.ipsl.polytechnique.fr (Linux)
;
;   * work on loholt1
;
; - fplod 20110420T085113Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * make it work on cratos
;   * remove hard coding path
;   * add graphviz
;
; - fplod 20110411T142955Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * minimal header
;
;-
pro fig4_met_var_correction_scatter
@cm_general
@cm_project
reinitplt, /z,/invert
key_portrait = 1
;
openps, FILENAME = project_od_env+'fig4_met_var_correction_scatter.ps'
fi=project_id_env+'sst_correction_final.txt'
res=read_ascii(fi,data_start=0)
ff=res.field1
cor=reform(ff(0,*))
bias=reform(ff(1,*))
std=reform(ff(2,*))
mean=reform(ff(4,*))
;
splot, mean, bias, small=[2,3,1],/noer, xtitle='Mean ERAI SST', ytitle='ERAI SST bias', $
       psym=2, charsize=1.,  $
       xrange=[20,33], yrange=[-0.7,0.7], xmin=1, ymin=1
oplot, [20,32], [0,0]
xx=total(std)/n_elements(std)
yy=total(bias)/n_elements(bias)
;
xyouts, 22, 0.6, 'bias=-0.05', charsize=1.1
xyouts, 22, 0.5, 'std ratio=0.989', charsize=1.1
;
print, xx, yy
ab=linfit(mean, bias,yfit=yfit)
a=float(ab(0))
b=float(ab(1))
oplot, mean, yfit, thick=3, color=50
print, a,b
;
; significant test
significance_test_99,mean,bias
;
fi=project_id_env+'t2m_correction_final.txt'
res=read_ascii(fi,data_start=0)
ff=res.field1
cor=reform(ff(0,*))
bias=reform(ff(1,*))
std=reform(ff(2,*))
mean=reform(ff(4,*))
;
xx=total(std)/n_elements(std)
yy=total(bias)/n_elements(bias)
print, xx, yy
;
splot, mean, bias, small=[2,3,2],/noer, xtitle='Mean ERAI T2m', ytitle='ERAI T2m bias', $
       psym=2, charsize=1.,  $
       xrange=[20,31], yrange=[-1,0.6], xmin=1, ymin=1
oplot, [20,32], [0,0]
;
xyouts, 22, 0.5, 'bias=-0.296', charsize=1.1
xyouts, 22, 0.4, 'std ratio=0.92', charsize=1.1
;
ab=linfit(mean, bias,yfit=yfit)
a=float(ab(0))
b=float(ab(1))
oplot, mean, yfit, thick=3, color=50
print, a,b
;
; significant test
significance_test_99,mean,bias
;
fi=project_id_env+'q2m_correction_final.txt'
res=read_ascii(fi,data_start=0)
ff=res.field1
cor=reform(ff(0,*))
bias=reform(ff(1,*))
std=reform(ff(2,*))
mean=reform(ff(4,*))
;
xx=total(std)/n_elements(std)
yy=total(bias)/n_elements(bias)
print, xx, yy
;
splot, mean, bias, small=[2,3,3],/noer, xtitle='Mean ERAI Q2m', ytitle='ERAI Q2m bias', $
       psym=2, charsize=1.,  $
       xrange=[12,21], yrange=[-1.5,0.8], xmin=1,ymin=1
oplot, [12,32], [0,0]
xyouts, 14, 0.6, 'bias=-0.79', charsize=1.1
xyouts, 14, 0.5, 'std ratio=0.92', charsize=1.1
;
ab=linfit(mean, bias,yfit=yfit)
a=float(ab(0))
b=float(ab(1))
oplot, mean, yfit, thick=3, color=50
print, a,b
;
; significant test
significance_test_99,mean,bias
fi=project_id_env+'ws_correction_final.txt'
res=read_ascii(fi,data_start=0)
ff=res.field1
cor=reform(ff(0,*))
bias=reform(ff(1,*))
std=reform(ff(2,*))
mean=reform(ff(4,*))
;
xx=total(std)/n_elements(std)
yy=total(bias)/n_elements(bias)
print, xx, yy
;
;
splot, mean, bias, small=[2,3,4],/noer, xtitle='Mean ERAI WS', ytitle='ERAI WS bias', $
        psym=2, charsize=1.,  $
       xrange=[2,9], yrange=[-1,0.8], xmin=1, ymin=1
oplot, [0,10], [0,0]
xyouts, 3, 0.7, 'bias=-0.28', charsize=1.1
xyouts, 3, 0.6, 'std ratio=0.90', charsize=1.1
;
ab=linfit(mean, bias,yfit=yfit)
a=float(ab(0))
b=float(ab(1))
oplot, mean, yfit, thick=3, color=50
;
print, a,b
; significant test
significance_test_99,mean,bias
;
closeps
;
end
